.. fnapy documentation master file, created by
   sphinx-quickstart on Fri Sep  9 10:45:33 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fnapy's documentation!
=================================

.. automodule:: fnapy_manager

.. toctree::
   :maxdepth: 2

   quickstart
   api
   CHANGELOG


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

